==> enqueue-client-0.0.8.tgz: package/lib/LockClient.js <==
/**
 * Created by VinceZK on 5/1/17.
 */
const net = require('net');
const uuidV1 = require('uuid/v1');

function lock(elementaryLock,callback){
    elementaryLock['uuid'] = uuidV1();
    var req = {reqUUID: uuidV1(), OP:'1', eleLock:elementaryLock};
    _requestEnqueueServer(req,(err,res)=>{
        if(err)return callback(elementaryLock.uuid,'3',err);
        switch (res.RC){
            case '0':
                callback(elementaryLock.uuid, res.RC);
                break;
            case '1':
                callback(elementaryLock.uuid, res.RC, res.OWNER);
                break;
            case '4':
                callback(elementaryLock.uuid, res.RC, res.MSG);
                break;
            default :
        }
    });
}

function unlock(lockUUID,callback){
    var req = {reqUUID: uuidV1(), OP:'2', lockUUID:lockUUID};
    _requestEnqueueServer(req,(err, res)=>{
        if(err)return callback('3',err);
        callback(res.RC,res.MSG);
    });
}

function promote(lockUUID,callback){
    var req = {reqUUID: uuidV1(), OP:'3', lockUUID:lockUUID};
    _requestEnqueueServer(req,(err, res)=>{
        if(err)return callback('3',err);
        callback(res.RC,res.MSG);
    });
}

function getLocksBy(lockName, lockOwner, callback){
    var req = {reqUUID: uuidV1(), OP:'4', lockName:lockName, lockOwner:lockOwner};
    _requestEnqueueServer(req,(err, res)=>{
        if(err)callback('3',err);
        else callback('0',res.locks);
    });
}

function _requestEnqueueServer(req,callback){
    var leftPart = "";
    var client = net.createConnection(3721, "127.0.0.1", function(){
        client.write(JSON.stringify(req)+"#");
        client.on('data',(res)=>{
            let temp = leftPart.concat(res.toString());
            let results = temp.split("#");
            leftPart = results.pop();
            var rightRes = results.find(function(element){
                return JSON.parse(element).reqUUID = req.reqUUID;
            });
            if(rightRes){
                client.end();
                callback(null, JSON.parse(rightRes));
            }
        })
    });

    client.on('error',function(err){
        callback(err);
    })
}

export {lock, unlock, promote, getLocksBy};

==> enqueue-client-0.0.10.tgz: package/lib/LockClient.js <==
/**
 * Created by VinceZK on 5/1/17.
 */
const net = require('net');

var reqUUID;
var lockUUID;

function lock(elementaryLock,callback){
    elementaryLock['uuid'] = _getReqUUID();
    var req = {reqUUID: _getLockUUID(), OP:'1', eleLock:elementaryLock};
    _requestEnqueueServer(req,(err,res)=>{
        if(err)return callback(elementaryLock.uuid,'3',err);
        switch (res.RC){
            case '0':
                callback(elementaryLock.uuid, res.RC);
                break;
            case '1':
                callback(elementaryLock.uuid, res.RC, res.OWNER);
                break;
            case '4':
                callback(elementaryLock.uuid, res.RC, res.MSG);
                break;
            default :
        }
    });
}

function unlock(lockUUID,callback){
    var req = {reqUUID: _getReqUUID(), OP:'2', lockUUID:lockUUID};
    _requestEnqueueServer(req,(err, res)=>{
        if(err)return callback('3',err);
        callback(res.RC,res.MSG);
    });
}

function promote(lockUUID,callback){
    var req = {reqUUID: _getReqUUID(), OP:'3', lockUUID:lockUUID};
    _requestEnqueueServer(req,(err, res)=>{
        if(err)return callback('3',err);
        callback(res.RC,res.MSG);
    });
}

function getLocksBy(lockName, lockOwner, callback){
    var req = {reqUUID: _getReqUUID(), OP:'4', lockName:lockName, lockOwner:lockOwner};
    _requestEnqueueServer(req,(err, res)=>{
        if(err)callback('3',err);
        else callback('0',res.locks);
    });
}

function _requestEnqueueServer(req,callback){
    var leftPart = "";
    var client = net.createConnection(3721, "127.0.0.1", function(){
        client.write(JSON.stringify(req)+"#");
        client.on('data',(res)=>{
            let temp = leftPart.concat(res.toString());
            let results = temp.split("#");
            leftPart = results.pop();
            var rightRes = results.find(function(element){
                return JSON.parse(element).reqUUID === req.reqUUID;
            });
            if(rightRes){
                //client.end();
                callback(null, JSON.parse(rightRes));
            }
        })
    });

    client.on('error',function(err){
        callback(err);
    })
}

function _getReqUUID(){
    return reqUUID++;
}

function _getLockUUID(){
    return lockUUID++;
}
export {lock, unlock, promote, getLocksBy};
